@@ -24,7 +24,7 @@ class UtilityFunctionTests(TestCase):
             field_verbose="stuff",
             filter_type = 'contains',
             filter_value = 'Lots of spam')
-    
+
     def get_fields_names(self, fields):
         names = []
         for field in fields:
@@ -52,7 +52,7 @@ class UtilityFunctionTests(TestCase):
         if 'custom_field' in settings.INSTALLED_APPS:
             from custom_field.models import CustomField
             cf = CustomField.objects.create(
-                name="foo", 
+                name="foo",
                 content_type=self.report_ct,
                 field_type='t',)
             fields = get_custom_fields_from_model(Report)
@@ -85,50 +85,3 @@ class UtilityFunctionTests(TestCase):
             objects, message = self.report.get_query()
             #expect custom manager to return correct object with filters
             self.assertEquals(objects[0], self.report)
-
-
-class ViewTests(TestCase):
-    def setUp(self):
-        self.user = User.objects.create_user('user', 'temporary@example.com', 'user')
-        self.user.is_staff = True
-        self.user.save()
-        self.c = Client()
-        self.c.login(username="user", password="user")
-        self.report_ct = ContentType.objects.get_for_model(Report) 
-        self.report = Report.objects.create(
-            name="foo report",
-            root_model=self.report_ct)
-        self.filter_field = FilterField.objects.create(
-            report=self.report,
-            field="X",
-            field_verbose="stuff",
-            filter_type = 'contains',
-            filter_value = 'Lots of spam')
-
-    def test_ajax_get_related(self):
-        response = self.c.get('/report_builder/ajax_get_related/', {
-            'field': 'user_created',
-            'model': self.report_ct.id,
-            'path': '',
-            'path_verbose': '',
-            })
-        self.assertContains(response, "report_starred_set")
-        self.assertContains(response, "user_permissions")
-        self.assertContains(response, "report_modified_set")
-
-    def test_ajax_get_fields(self):
-        response = self.c.get('/report_builder/ajax_get_fields/', {
-            'model': self.report_ct.id,
-            'field': 'displayfield',
-            'path': '',
-            'path_verbose': '',
-            })
-        self.assertContains(response, 'data-name="aggregate"')
-        self.assertContains(response, 'data-path="displayfield__"')
-        self.assertContains(response, "field")
-        self.assertContains(response, "field verbose")
-        self.assertContains(response, "group")
-        self.assertContains(response, "ID [AutoField]")
-        self.assertContains(response, "name [CharField]")
-        self.assertContains(response, "path [CharField]")
-
